Learn R Programming

minter (version 0.1.0)

.simple_SMD: Simple effect: Standardized Mean Difference

Description

Computes the individual or simple effect of Factor A over the Control.

Usage

.simple_SMD(
  Ctrl_mean,
  Ctrl_sd,
  Ctrl_n,
  A_mean,
  A_sd,
  A_n,
  hedges_correction = TRUE
)

Value

A data frame containing the effect sizes and their sampling variance. By default, the columns are named yi (effect size) and vi (sampling variance). If append = TRUE, the results are appended to the input data; otherwise, only the computed effect size columns are returned.

Arguments

Ctrl_mean

Mean outcome from the Control treatment

Ctrl_sd

Standard deviation from the control treatment

Ctrl_n

Sample size from the control treatment

A_mean

Mean outcome from the experimental treatment

A_sd

Standard deviation from the experimental treatment

A_n

Sample size from the experimental treatment

hedges_correction

Boolean. If TRUE correct for small-sample bias. Default is TRUE.

Author

Facundo Decunta - fdecunta@agro.uba.ar

Details

It is the classic Standardized Mean Difference (SMD), which can also be computed with metafor's escalc() function using measure = "SMD".

See the package vignette for a detailed description of the formula.

References

Gurevitch, J., Morrison, J. A., & Hedges, L. V. (2000). The interaction between competition and predation: a meta-analysis of field experiments. The American Naturalist, 155(4), 435-453.

Morris, W. F., Hufbauer, R. A., Agrawal, A. A., Bever, J. D., Borowicz, V. A., Gilbert, G. S., ... & Vázquez, D. P. (2007). Direct and interactive effects of enemies and mutualists on plant performance: a meta‐analysis. Ecology, 88(4), 1021-1029. https://doi.org/10.1890/06-0442

Examples

Run this code
data <- data.frame(
  study_id = 1:3,
  control_mean = c(45.2, 52.8, 38.9),
  control_sd = c(8.1, 11.2, 7.3),
  control_n = c(18, 23, 16),
  pollinator_exclusion_mean = c(28.7, 35.4, 22.1),
  pollinator_exclusion_sd = c(6.8, 9.1, 5.9),
  pollinator_exclusion_n = c(20, 22, 18)
)

# With Hedges' correction (default)
result <- SMD_ind(
  data = data,
  Ctrl_mean = "control_mean",
  Ctrl_sd = "control_sd",
  Ctrl_n = "control_n",
  A_mean = "pollinator_exclusion_mean",
  A_sd = "pollinator_exclusion_sd",
  A_n = "pollinator_exclusion_n",
  hedges_correction = TRUE
)

# Without Hedges' correction
result_no_hedges <- SMD_ind(
  data = data,
  Ctrl_mean = "control_mean",
  Ctrl_sd = "control_sd",
  Ctrl_n = "control_n",
  A_mean = "pollinator_exclusion_mean",
  A_sd = "pollinator_exclusion_sd",
  A_n = "pollinator_exclusion_n",
  hedges_correction = FALSE
)

Run the code above in your browser using DataLab