Learn R Programming

minter (version 0.1.0)

.time_interaction_lnVR: Log of Variability Ratio: Interaction Between Experimental Treatment and Time

Description

Log of Variability Ratio: Interaction Between Experimental Treatment and Time

Usage

.time_interaction_lnVR(
  t0_Ctrl_sd,
  t1_Ctrl_sd,
  Ctrl_n,
  Ctrl_cor,
  t0_Exp_sd,
  t1_Exp_sd,
  Exp_n,
  Exp_cor
)

Arguments

t0_Ctrl_sd

Standard deviation from the control group at time 0

t1_Ctrl_sd

Standard deviation from the control group at time 1

Ctrl_n

Sample size of the control group

Ctrl_cor

Correlation between the means of the control group at t0 and t1

t0_Exp_sd

Standard deviation from the experimental group at time 0

t1_Exp_sd

Standard deviation from the experimental group at time 1

Exp_n

Sample size of the experimental group

Exp_cor

Correlation between the means of the experimental group at t0 and t1