View source: R/lnCVR_wrappers.R
| lnCVR_main | R Documentation |
Computes the main effect of Factor A across levels of Factor B in factorial experiments on the coefficient of variation.
lnCVR_main(
data,
col_names = c("yi", "vi"),
append = TRUE,
Ctrl_mean,
Ctrl_sd,
Ctrl_n,
A_mean,
A_sd,
A_n,
B_mean,
B_sd,
B_n,
AB_mean,
AB_sd,
AB_n
)
data |
Data frame containing the variables used. |
col_names |
Vector of two strings to name the output columns for the effect size and its sampling variance. Default is 'yi' and 'vi'. |
append |
Logical. Append the results to |
Ctrl_mean |
Mean outcome from the Control treatment |
Ctrl_sd |
Standard deviation from the control treatment |
Ctrl_n |
Sample size from the control treatment |
A_mean |
Mean outcome from the treatment |
A_sd |
Standard deviation from the treatment |
A_n |
Sample size from the treatment |
B_mean |
Mean outcome from the B treatment |
B_sd |
Standard deviation from the B treatment |
B_n |
Sample size from the B treatment |
AB_mean |
Mean outcome from the interaction AxB treatment |
AB_sd |
Standard deviation from the interaction AxB treatment |
AB_n |
Sample size from the interaction AxB treatment |
See the package vignette for a detailed description of the formula.
A data frame containing the effect sizes and their sampling variance.
By default, the columns are named yi (effect size) and vi (sampling variance).
If append = TRUE, the results are appended to the input data; otherwise, only the computed effect size columns are returned.
Facundo Decunta - fdecunta@agro.uba.ar
data <- data.frame(
study_id = 1:2,
control_mean = c(14.2, 16.8), control_sd = c(2.8, 3.1), control_n = c(16, 14),
irrigation_mean = c(19.5, 22.1), irrigation_sd = c(5.2, 5.8), irrigation_n = c(15, 16),
co2_mean = c(16.8, 19.4), co2_sd = c(3.1, 3.6), co2_n = c(17, 13),
irrigation_co2_mean = c(24.3, 27.9), irrigation_co2_sd = c(6.8, 7.4), irrigation_co2_n = c(14, 15)
)
result <- lnCVR_main(
data = data,
Ctrl_mean = "control_mean", Ctrl_sd = "control_sd", Ctrl_n = "control_n",
A_mean = "irrigation_mean", A_sd = "irrigation_sd", A_n = "irrigation_n",
B_mean = "co2_mean", B_sd = "co2_sd", B_n = "co2_n",
AB_mean = "irrigation_co2_mean", AB_sd = "irrigation_co2_sd", AB_n = "irrigation_co2_n"
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.